/***************************************************************************

    M.A.M.E.CE3  -  Multiple Arcade Machine Emulator for Pocket PC
    Win32 Portions Copyright (C) 1997-98 Michael Soderstrom and Chris Kirmse
    
    This file is part of MAMECE3, and may only be used, modified and
    distributed under the terms of the MAME license, in "MAME.txt".
    By continuing to use, modify or distribute this file you indicate
    that you have read the license and understand and accept it fully.

 ***************************************************************************/

 /***************************************************************************

  options.c

  Stores global options and per-game options;

***************************************************************************/



#include "options.h"
#include "Playgame.h"


//#include "MameCE.h"


/***************************************************************************
    Internal function prototypes
 ***************************************************************************/

/***************************************************************************
    Internal structures
 ***************************************************************************/

/***************************************************************************
    Internal variables
 ***************************************************************************/


/***************************************************************************
    External variables
 ***************************************************************************/
/* Added these for the Getmodule Function */

WORD modpath[MAX_PATH];
static char szRootPath[MAX_PATH];
char *p;
char name[MAX_PATH];


/***************************************************************************
    External functions  
 ***************************************************************************/

void OptionsInit()
{
    int i;


    tGlobal.use_default = FALSE;

    tGlobal.is_window        = FALSE;
    tGlobal.display_best_fit = TRUE;
    tGlobal.display_monitor  = 0;    /* Primary Display */
    tGlobal.width            = 480;
    tGlobal.height           = 320;
    tGlobal.skip_lines       = 0;
    tGlobal.skip_columns     = 0;
    tGlobal.double_vector    = FALSE;
    tGlobal.window_ddraw     = TRUE;
    tGlobal.auto_frame_skip  = options.disable_throttle; //TRUE; //Techmaster
    tGlobal.frame_skip       = 0;
    tGlobal.use_dirty        = FALSE;
    tGlobal.hscan_lines      = TRUE;
    tGlobal.vscan_lines      = FALSE;
    tGlobal.use_blit         = FALSE;
    tGlobal.disable_mmx      = TRUE;
    tGlobal.scale            = 2;
    tGlobal.rotate           = ROTATE_NONE;
    tGlobal.flipx            = FALSE;
    tGlobal.flipy            = FALSE;
    tGlobal.gamma            = 1.0;
    tGlobal.brightness       = 100;
    tGlobal.depth            = 8;
    tGlobal.antialias        = TRUE;
    tGlobal.translucency     = TRUE;
    tGlobal.beam             = 1.0;
    tGlobal.flicker          = 0;

    tGlobal.use_joystick = FALSE;
    tGlobal.use_ai_mouse = TRUE;
    tGlobal.di_keyboard  = TRUE;
    tGlobal.di_joystick  = TRUE;

    for (i=0;i<4;i++)
    {
       tGlobal.physical_joysticks[i] = i;
       tGlobal.x_axes[i] = 0;
       tGlobal.y_axes[i] = 1;
    }

    tGlobal.sound        = SOUND_WAVE;
    tGlobal.sample_rate  = 11025;
    tGlobal.sample_bits  = 8;
    tGlobal.volume       = 0;
    tGlobal.stereo       = FALSE;

    tGlobal.fm_ym3812    = FALSE;

    tGlobal.cheat        = FALSE;
    tGlobal.auto_pause   = TRUE;
    tGlobal.error_log    = FALSE;
    tGlobal.profile      = FALSE;
    tGlobal.showfps      = FALSE;
    tGlobal.use_artwork  = TRUE;
    tGlobal.use_samples  = TRUE;

    tGlobal.play_count   = 0;
    tGlobal.has_roms     = UNKNOWN;
    tGlobal.has_samples  = UNKNOWN;
    tGlobal.is_favorite  = FALSE;

    /* This allocation should be checked */
    /*game = (options_type *)malloc(num_games * sizeof(options_type));

    for (i = 0; i < num_games; i++)
    {
        game[i] = global;
        game[i].use_default = TRUE;
    }*/

}

void OptionsExit()
{
    free(game);
    free(settings.romdirs);
    free(settings.sampledirs);
    free(settings.cfgdir);
    free(settings.hidir);
}


options_type * GetDefaultOptions()
{
    return &global;
}

options_type * GetGameOptions(int num_game)
{
    int play_count;
    int has_roms;
    int has_samples;

    assert(0 <= num_game && num_game < num_games);

    play_count  = game[num_game].play_count;
    has_roms    = game[num_game].has_roms;
    has_samples = game[num_game].has_samples;

    if (game[num_game].use_default)
    {
        game[num_game]              = global;
        game[num_game].use_default  = TRUE;
        game[num_game].play_count   = play_count;
        game[num_game].has_roms     = has_roms;
        game[num_game].has_samples  = has_samples;
    }
    return &game[num_game];
}

void SetVersionCheck(BOOL version_check)
{
    settings.version_check = version_check;
}

BOOL GetVersionCheck(void)
{
    return settings.version_check;
}

const char* GetRomDirs(void)
{
    return settings.romdirs;
}

void SetRomDirs(const char* paths)
{
    if (settings.romdirs != NULL)
    {
        free(settings.romdirs);
        settings.romdirs = NULL;
    }

    if (paths != NULL)
        settings.romdirs = strdup(paths);
}

const char* GetSampleDirs(void)
{
    return settings.sampledirs;
}

void SetSampleDirs(const char* paths)
{
    if (settings.sampledirs != NULL)
    {
        free(settings.sampledirs);
        settings.sampledirs = NULL;
    }

    if (paths != NULL)
        settings.sampledirs = strdup(paths);
}

const char* GetCfgDir(void)
{
    return settings.cfgdir;
}

void SetCfgDir(const char* path)
{
    if (settings.cfgdir != NULL)
    {
        free(settings.cfgdir);
        settings.cfgdir = NULL;
    }

    if (path != NULL)
        settings.cfgdir = strdup(path);
}

const char* GetHiDir(void)
{
    return settings.hidir;
}

void SetHiDir(const char* path)
{
    if (settings.hidir != NULL)
    {
        free(settings.hidir);
        settings.hidir = NULL;
    }

    if (path != NULL)
        settings.hidir = strdup(path);
}

int  GetHasRoms(int num_game)
{
    assert(0 <= num_game && num_game < num_games);

    return game[num_game].has_roms;
}

void SetHasRoms(int num_game, int has_roms)
{
    assert(0 <= num_game && num_game < num_games);

    game[num_game].has_roms = has_roms;
}

int  GetHasSamples(int num_game)
{
    assert(0 <= num_game && num_game < num_games);

    return game[num_game].has_samples;
}

void SetHasSamples(int num_game, int has_samples)
{
    assert(0 <= num_game && num_game < num_games);

    game[num_game].has_samples = has_samples;
}

/***************************************************************************
    Internal functions
 ***************************************************************************/


/* End of options.c */
