/*
	File:			host.h

	Description:	Host header file.

	Author:			Roger Flores

	Copyright:		Copyright  2003 by Tapwave, Inc.

	Disclaimer:		IMPORTANT:  This Tapwave software is provided by Tapwave, Inc. ("Tapwave").  Your 
					use is subject to and governed by terms and conditions of the Software Development 
					Kit Agreement ("SDK Agreement") between you and Tapwave.  If you have not entered 
					into Tapwaves standard SDK Agreement with Tapwave, you have no right or license 
					to use, reproduce, modify, distribute or otherwise exploit this Tapwave software.  
					You may obtain a copy of Tapwaves standard SDK Agreement by calling 650-960-1817
					or visiting Tapwave at http://www.tapwave.com/developers/. 

	Change History (most recent first):
				
*/

/* Define how some common types are defined on the
host machine.
*/

#ifndef HOSTPALM_H
#define HOSTPALM_H


#define appcreatorid	'PDac'

typedef signed char int8;
typedef unsigned char uint8;
typedef signed short int16;
typedef unsigned short uint16;
typedef long int32;
typedef unsigned long uint32;
typedef long intptr;
typedef unsigned long uintptr;
typedef unsigned char byte;
#define word UInt16 
#define dword UInt32
// TYPES //////////////////////////////////////////////////

// basic unsigned types
typedef unsigned short USHORT;
typedef unsigned short WORD;
typedef unsigned char  UCHAR;
typedef unsigned char  BYTE;
typedef unsigned int   QUAD;
typedef unsigned int   UINT;
typedef unsigned long	DWORD;

#ifndef __cplusplus
typedef unsigned char bool;
#endif

#ifndef NULL
#define NULL	0
#endif

#include <PalmOS.h>
#include <TwTraps.h>
#include <TwGfx.h>

// The API to the host functions is C based.
#ifdef __cplusplus
extern "C"
{
#endif

// Define this to run full speed.  Leave undefined to run at a constant 
// frame rate.
#define OPTION_DELAY_NONE 1
#define appFileCreator 'PDac'

#define FPS_DATA_MAX 300
typedef struct
{
	int time[FPS_DATA_MAX];
	int count;
	int time_of_last_data_out;
} FPSType;

/*
 * UI and graphics for Palm OS software are often edited using the 
 * Constructor tool.  Constructor can be told to describe the UI and
 * graphic resources in a header file.  That header is included here.
 */

//AK defines for getting and setting preferences for driver database
#define appPrefVersionNum	1	//AK Set application prefs version here

#define AppModuleSizePref	0x01
#define AppDriverList		0x02
#define AppRunGameIndex		0x03
#define AppLastModuleListed	0x04
#define AppSoundOption		0x05 //Int16 holding Sound Hz
#define AppRotateOption		0x06 //Int16 holding Sound Hz

#define AppScale			0x10 //UInt8 holding scaling info
#define AppKeyOption		0x11 //Struct holding key assignments
#define AppMenuOption		0x12 //UInt8 holding menu orientation (0=none, 1=horiz, 2=vert)
#define AppCPUSpeed			0x13
#define AppAudioSpeed		0x14 //UInt8 holding CPU and Audio percent of speed (under/overclock)

//MESS
#define AppMESSCommandLine	0x20	//Holds the command line string (max 256);

#define FTR_BT_PORT_ID       0x30
#define FTR_BT_PORT_OPEN_ID  0x31
#define FTR_SER_PORT_ID      0x32
#define FTR_SER_PORT_OPEN_ID 0x33
#define FTR_IR_PORT_ID       0x34
#define FTR_IR_PORT_OPEN_ID  0x35
#define FTR_OPT_INPUTCONF_TREO_ID 0x36

#define FTR_OPT_BTGP_USED_ID     0x35
#define FTR_OPT_BTGP_CLOSED_ID   0x36
#define FTR_OPT_SERIAL_PORTID_ID 0x37
#define FTR_OPT_IRKB_USED_ID     0x38
#define FTR_OPT_IRKB_CONFIG_ID   0x39

typedef struct 
{
  Int32 joyX;
  Int32 joyY;
  Int32 ActionA;
  Int32 ActionB;
  Int32 ActionC;
  Int32 ActionD;
  Int32 TriggerA;
  Int32 TriggerB;
  Int32 Launch;
  Int32 Calc;
  Int32	Select;
  Int32 PenX;
  Int32 PenY;
  Int32 PenDown;
  Int32 Power;
} AppJoystickInput;

typedef enum
{
	ConfigExit = 0,
	ConfigP1Credit,
	ConfigP1Start,
	ConfigUp,
	ConfigDown,
	ConfigLeft,
	ConfigRight,
	ConfigButton1,
	ConfigButton2,
	ConfigButton3,
	ConfigButton4,
	ConfigMenu,
	ConfigMenuSelect,
	ConfigPause,
	ConfigReset,
	ConfigLast
} ConfigKeyType;

// for calling back from pno to host
typedef struct {
  UInt32 a;
  UInt32 b;
  UInt32 c;
  UInt32 d;
} hostcall_t;

typedef struct {
  UInt32 a;
  UInt32 b;
  UInt32 c;
  UInt32 d;
  UInt32 e;
  UInt32 f;
  UInt32 g;
  UInt32 h;
  UInt32 i;
} bighostcall_t;

typedef struct
{
	int irkeycode; //code from the ir keyboard
	unsigned ircode; //mame equiv for ex: 'A'
	int pressed; //1=pressed

} ircodelistType;

extern char *ConfigKeysP[30];
extern char ConfigKeysText[30][40]; 

typedef struct
{
	UInt32 Key;
} KeyStructType;

extern KeyStructType KeyStruct[15];


// Host provided functions
    extern void HostMaskKeys(void);
    extern void HostUnmaskKeys(void);
    extern long int HostGetConsoleInput(void);
    extern void GamePlaySounds(void);
    extern void HostDrawObject(int bitmapNumber,
    short int x,
    short int y);
    extern void HostDrawGameMenu(int left,
        int top,
        int width,
        int height);
    extern void HostDrawPoint(int x,
        int y);
    extern void HostFlushPoints(void);
    extern void HostNewScreenBuffer(short int buffer_width,
    short int buffer_height);

    extern void HostDrawBuffer(short int destX,
    short int destY,
    short int sourceX,
    short int sourceY,
    short int sourceWidth,
    short int sourceHeight);
    extern long int HostPeriodDuration(void);
// extern void HostSetForeColor(ColorType color);

// extern void HostSetBackColor(ColorType color);

    extern void HostOpenScreenBuffer(void);
    extern void HostCloseScreenBuffer(void);
    extern int HostGetBitmapWidth(int bitmapNumber);
    extern int HostGetBitmapHeight(int bitmapNumber);
	
	extern AppJoystickInput InputPool;
	extern void PlaySample(unsigned char *sample);
	extern Err MameAppStart();
	extern void MameAppStop();
	extern UInt32 *host_event_handler;
	extern void *MemGluePtrNewL ( UInt32 foo );


typedef struct 

  {

	 Int16 *			startP;
	 Int16 *			currP;
	 Int16 *			endP;
	 Int16		size;
	 Int16		stereo;
	 volatile Boolean			active;
	 Boolean	looping;

  }AudioDataBlockType;
  
typedef struct
{
	UInt16 *rowbytes;
	int bmWidth;
	int bmHeight;

}HBITMAP;

typedef struct
{
	HBITMAP StatIcons[16];
	RectangleType	RectStat[16];
	BitmapType	*StatBitmapLow[16];
	BitmapType	*StatBitmap[16];
}StatusBarType;


    //extern TwGfxSurfaceType * pictureBitmapP[ObjectBitmapCount];
    //! These are only used if customBlitting is true.  They cache some of the info on
    //! the pictures that will be used often.  Custom blitting means using 
    //! a custom blitter drawing to a frame buffer, versus using the standard
    //! API calls.
    extern Boolean customBlitting;
    extern Boolean isInputMasked;
    extern UInt16 soundAmp;            // default sound amplitude
    extern UInt32 screenWidth;
    extern UInt32 screenHeight;
    extern UInt32 screenPitch;
    extern UInt32 menuWidth;
    extern UInt32 menuHeight;
	extern StatusBarType StatusBar;
	extern StatusBarType StatusBar8;

	extern int MenuOption;
	extern UInt8 iCPUSpeed;
	extern UInt8 iAudioSpeed;


	// This is the offscreen buffer which is copied to the screen.
    extern UInt8 * screenBufferP;  // DOLATER - This is really a pointer to the pixels!
	extern TwGfxSurfaceType * screenBufferH;    // screenBuffer
    extern TwGfxType * GFX;
    extern TwGfxSurfaceType * displaySurface;

    //! These are used to get the input.  isInputMasked prevents them
    //! from being set or unset repeatedly.  The padding inserted is
	//! to achieve ARM alignment for these data structures.
	//! NOTE: replace with compiler options when CW9 is avaiable.
    extern AppJoystickInput joystickInput;
    extern Int32 *inputFormatP;
    //! Indicates which game menu item is selected.
    extern Int16 gameMenuSelected;
    //! Controls when the next cycle starts
    extern UInt32 cycleNextTime;
    extern UInt32 cycleDurationTime;
    extern UInt32 ZRotateEnable;
    extern UInt8 ZScreenStretch; //AK - 0 means no stretch, 1 means fit to screen
	extern UInt32 screenDepth;
	extern WinHandle offScreenH;
	extern WinHandle oldDrawWinH;



extern bool stream_is_playing;
	extern bool custom_blitting;

  extern AudioDataBlockType dataBlock;
extern UInt32 ZSoundEnable; //AK choose to enable sound or not. Now holds sample rate

extern Err err;

 extern SndStreamRef Zstream;
 extern UInt8 *screenBufferScaleP;

 
 
// Game provided functions.
#define game_pause 1
#define game_run 0

    extern void game_set_pause(int value);
    extern int game_get_pause(void);
    extern void game_new(int width,
        int height,
        int random_number_seed);
	extern int game_exists(void);
    extern int game_advance(unsigned long int keys, long int joystickX, long int joystickY);

    extern void game_delete(void);
extern void HostFastDrawLive(UInt8 *buffer, int x, int y, int width, int height, UInt16 *pal16, int IAdjustBase);

extern UInt8 *ScreenDestP;
extern Boolean IsZodiac;
extern UInt32 g_bt_gamepadused;
extern UInt32 g_bt_gamepadclosed;
extern UInt32 g_n_serportid;
extern UInt32 g_ir_keyboardused;
extern void    (*irhandler) (void);
extern ircodelistType *ircodelist;


// for requesting data from the 68k side, from the pnolet
#define BRIDGESHIFT 6
#define BRIDGEMASK  0x3F

enum{
  BRIDGE_SrmSend=1,
  BRIDGE_SrmReceive,
  BRIDGE_SrmReceiveCheck,
  BRIDGE_TreoKey
};

extern char PALMPREFIXDIR[256];
extern char PALMVFSDIR[50];
extern char PALMOPENDIR[50];

#define OFFSCREEN_BUFFER_WIDTH 640
#define OFFSCREEN_BUFFER_HEIGHT 640


// color ranges
#define COLOR_RED_START                   0
#define COLOR_RED_END                     5

#define COLOR_GREEN_START                 12
#define COLOR_GREEN_END                   17

#define COLOR_BLUE_START                  6
#define COLOR_BLUE_END                    11

#define COLOR_WHITE_START                 18
#define COLOR_WHITE_END                   23


#ifdef __cplusplus
}
#endif

#endif